static char *rcsid = "$Header: /plaid/homes/zeus/Blind-2.47/cmds/RCS/z.c,v 2.47 1998/04/15 21:34:50 zeus Exp zeus $";

/*
 *
 * $Log: z.c,v $
 * Revision 2.47  1998/04/15 21:34:50  zeus
 * *** empty log message ***
 *
 * Revision 2.46  1997/04/18 12:13:56  zeus
 * *** empty log message ***
 *
 * Revision 2.45  1997/01/01  00:07:24  zeus
 *
 *
 */

#define NOTIMEB
 
#include "common.h"
#include "prototypes.h"
#include "enterturn-g.h"
#include "cmds.h"
#include "cmds-g.h"

extern char err_tmp[];

void z_cmd_rcsid (void);

void
z_cmd_rcsid (void)
{
  printf ("%s\n",rcsid);
}

#ifdef ZCMDOK
void
z_cmd (char *buf, player * P)
{
  char t[MAXSTRLEN];
  char newentry[MAXTEXT+MAXSTRLEN+2]; /* racename:maxstrlen +1 (:) + 1 */
  int l;
  
  cmd_init(buf);
  hstrncpy (t, next_token (), MAXSTRLEN);
  if (t[0])
  {
    if (strchr(t,(int) ':'))
    {
      error("Email addresses may not contain :'s\n");
      return;
    }
    /* Build new entry for races:passwords */
    hstrncpy (newentry,P->name,MAXTEXT);
    l = strlen(newentry);
    newentry[l]=':';
    newentry[l+1]='\0';
    /* This is safe, since hstrncpy null terminates t */
    strncat (newentry,t,MAXSTRLEN-MAXTEXT-2);
#ifndef PREPROC /* Do NOT reset if using preprocessor! */
    if (reset_email (P->name,newentry))
    {
      error (err_tmp);
      return;
    }
#endif
  }
  else
  {
    error ("New Address required!\n");
    return;
  }
  extra_token();
}

#else
void
z_cmd (char *buf, player * P)
{
  error ("This command is not enabled!\n");
}
#endif
